@@ -9,8 +9,8 @@ use crate::bounding_hierarchy::{BHShape, BoundingHierarchy};
 use crate::bvh::iter::BVHTraverseIterator;
 use crate::ray::Ray;
 use crate::utils::{concatenate_vectors, joint_aabb_of_shapes, Bucket};
+use crate::Point3;
 use crate::EPSILON;
-use nalgebra::Point3;
 use std::f32;
 use std::iter::repeat;
 
