@@ -520,8 +520,8 @@ mod tests {
     use crate::testbase::{
         build_some_bh, create_n_cubes, default_bounds, randomly_transform_scene, UnitBox,
     };
+    use crate::Point3;
     use crate::EPSILON;
-    use nalgebra::Point3;
     use std::collections::HashSet;
 
     #[test]
