@@ -3,30 +3,44 @@
 
 use crate::aabb::AABB;
 use crate::EPSILON;
-use nalgebra::{Point3, Vector3};
+use crate::{Point3, Vector3};
 use std::f32::INFINITY;
 
 /// A struct which defines a ray and some of its cached values.
 #[derive(Debug)]
 pub struct Ray {
     /// The ray origin.
-    pub origin: Point3<f32>,
+    pub origin: Point3,
 
     /// The ray direction.
-    pub direction: Vector3<f32>,
+    pub direction: Vector3,
 
     /// Inverse (1/x) ray direction. Cached for use in [`AABB`] intersections.
     ///
     /// [`AABB`]: struct.AABB.html
     ///
-    inv_direction: Vector3<f32>,
+    inv_direction: Vector3,
 
-    /// Sign of the direction. 0 means positive, 1 means negative.
+    /// Sign of the X direction. 0 means positive, 1 means negative.
     /// Cached for use in [`AABB`] intersections.
     ///
     /// [`AABB`]: struct.AABB.html
     ///
-    sign: Vector3<usize>,
+    sign_x: usize,
+
+    /// Sign of the Y direction. 0 means positive, 1 means negative.
+    /// Cached for use in [`AABB`] intersections.
+    ///
+    /// [`AABB`]: struct.AABB.html
+    ///
+    sign_y: usize,
+
+    /// Sign of the Z direction. 0 means positive, 1 means negative.
+    /// Cached for use in [`AABB`] intersections.
+    ///
+    /// [`AABB`]: struct.AABB.html
+    ///
+    sign_z: usize,
 }
 
 /// A struct which is returned by the `intersects_triangle` method.
@@ -56,7 +70,7 @@ impl Ray {
     /// # Examples
     /// ```
     /// use bvh::ray::Ray;
-    /// use bvh::nalgebra::{Point3,Vector3};
+    /// use bvh::{Point3,Vector3};
     ///
     /// let origin = Point3::new(0.0,0.0,0.0);
     /// let direction = Vector3::new(1.0,0.0,0.0);
@@ -68,17 +82,15 @@ impl Ray {
     ///
     /// [`Ray`]: struct.Ray.html
     ///
-    pub fn new(origin: Point3<f32>, direction: Vector3<f32>) -> Ray {
+    pub fn new(origin: Point3, direction: Vector3) -> Ray {
         let direction = direction.normalize();
         Ray {
             origin,
             direction,
             inv_direction: Vector3::new(1.0 / direction.x, 1.0 / direction.y, 1.0 / direction.z),
-            sign: Vector3::new(
-                (direction.x < 0.0) as usize,
-                (direction.y < 0.0) as usize,
-                (direction.z < 0.0) as usize,
-            ),
+            sign_x: (direction.x < 0.0) as usize,
+            sign_y: (direction.y < 0.0) as usize,
+            sign_z: (direction.z < 0.0) as usize,
         }
     }
 
@@ -89,7 +101,7 @@ impl Ray {
     /// ```
     /// use bvh::aabb::AABB;
     /// use bvh::ray::Ray;
-    /// use bvh::nalgebra::{Point3,Vector3};
+    /// use bvh::{Point3,Vector3};
     ///
     /// let origin = Point3::new(0.0,0.0,0.0);
     /// let direction = Vector3::new(1.0,0.0,0.0);
@@ -106,11 +118,11 @@ impl Ray {
     /// [`AABB`]: struct.AABB.html
     ///
     pub fn intersects_aabb(&self, aabb: &AABB) -> bool {
-        let mut ray_min = (aabb[self.sign.x].x - self.origin.x) * self.inv_direction.x;
-        let mut ray_max = (aabb[1 - self.sign.x].x - self.origin.x) * self.inv_direction.x;
+        let mut ray_min = (aabb[self.sign_x].x - self.origin.x) * self.inv_direction.x;
+        let mut ray_max = (aabb[1 - self.sign_x].x - self.origin.x) * self.inv_direction.x;
 
-        let y_min = (aabb[self.sign.y].y - self.origin.y) * self.inv_direction.y;
-        let y_max = (aabb[1 - self.sign.y].y - self.origin.y) * self.inv_direction.y;
+        let y_min = (aabb[self.sign_y].y - self.origin.y) * self.inv_direction.y;
+        let y_max = (aabb[1 - self.sign_y].y - self.origin.y) * self.inv_direction.y;
 
         if (ray_min > y_max) || (y_min > ray_max) {
             return false;
@@ -128,8 +140,8 @@ impl Ray {
         // Using the following solution significantly decreases the performance
         // ray_max = ray_max.min(y_max);
 
-        let z_min = (aabb[self.sign.z].z - self.origin.z) * self.inv_direction.z;
-        let z_max = (aabb[1 - self.sign.z].z - self.origin.z) * self.inv_direction.z;
+        let z_min = (aabb[self.sign_z].z - self.origin.z) * self.inv_direction.z;
+        let z_max = (aabb[1 - self.sign_z].z - self.origin.z) * self.inv_direction.z;
 
         if (ray_min > z_max) || (z_min > ray_max) {
             return false;
@@ -155,7 +167,7 @@ impl Ray {
     /// ```
     /// use bvh::aabb::AABB;
     /// use bvh::ray::Ray;
-    /// use bvh::nalgebra::{Point3,Vector3};
+    /// use bvh::{Point3,Vector3};
     ///
     /// let origin = Point3::new(0.0,0.0,0.0);
     /// let direction = Vector3::new(1.0,0.0,0.0);
@@ -201,7 +213,7 @@ impl Ray {
     /// ```
     /// use bvh::aabb::AABB;
     /// use bvh::ray::Ray;
-    /// use bvh::nalgebra::{Point3,Vector3};
+    /// use bvh::{Point3,Vector3};
     ///
     /// let origin = Point3::new(0.0,0.0,0.0);
     /// let direction = Vector3::new(1.0,0.0,0.0);
@@ -246,24 +258,19 @@ impl Ray {
     /// The distance is set to +INFINITY if the ray does not intersect the triangle, or hits
     /// it from behind.
     #[allow(clippy::many_single_char_names)]
-    pub fn intersects_triangle(
-        &self,
-        a: &Point3<f32>,
-        b: &Point3<f32>,
-        c: &Point3<f32>,
-    ) -> Intersection {
+    pub fn intersects_triangle(&self, a: &Point3, b: &Point3, c: &Point3) -> Intersection {
         let a_to_b = *b - *a;
         let a_to_c = *c - *a;
 
         // Begin calculating determinant - also used to calculate u parameter
         // u_vec lies in view plane
         // length of a_to_c in view_plane = |u_vec| = |a_to_c|*sin(a_to_c, dir)
-        let u_vec = self.direction.cross(&a_to_c);
+        let u_vec = self.direction.cross(a_to_c);
 
         // If determinant is near zero, ray lies in plane of triangle
         // The determinant corresponds to the parallelepiped volume:
         // det = 0 => [dir, a_to_b, a_to_c] not linearly independant
-        let det = a_to_b.dot(&u_vec);
+        let det = a_to_b.dot(u_vec);
 
         // Only testing positive bound, thus enabling backface culling
         // If backface culling is not desired write:
@@ -278,7 +285,7 @@ impl Ray {
         let a_to_origin = self.origin - *a;
 
         // Calculate u parameter
-        let u = a_to_origin.dot(&u_vec) * inv_det;
+        let u = a_to_origin.dot(u_vec) * inv_det;
 
         // Test bounds: u < 0 || u > 1 => outside of triangle
         if !(0.0..=1.0).contains(&u) {
@@ -286,16 +293,16 @@ impl Ray {
         }
 
         // Prepare to test v parameter
-        let v_vec = a_to_origin.cross(&a_to_b);
+        let v_vec = a_to_origin.cross(a_to_b);
 
         // Calculate v parameter and test bound
-        let v = self.direction.dot(&v_vec) * inv_det;
+        let v = self.direction.dot(v_vec) * inv_det;
         // The intersection lies outside of the triangle
         if v < 0.0 || u + v > 1.0 {
             return Intersection::new(INFINITY, u, v);
         }
 
-        let dist = a_to_c.dot(&v_vec) * inv_det;
+        let dist = a_to_c.dot(v_vec) * inv_det;
 
         if dist > EPSILON {
             Intersection::new(dist, u, v)
@@ -416,7 +423,7 @@ mod tests {
             let triangle = (tuple_to_point(&a), tuple_to_point(&b), tuple_to_point(&c));
             let u_vec = triangle.1 - triangle.0;
             let v_vec = triangle.2 - triangle.0;
-            let normal = u_vec.cross(&v_vec);
+            let normal = u_vec.cross(v_vec);
 
             // Get some u and v coordinates such that u+v <= 1
             let u = u % 101;
@@ -430,7 +437,7 @@ mod tests {
             // Define a ray which points at the triangle
             let origin = tuple_to_point(&origin);
             let ray = Ray::new(origin, point_on_triangle - origin);
-            let on_back_side = normal.dot(&(ray.origin - triangle.0)) <= 0.0;
+            let on_back_side = normal.dot(ray.origin - triangle.0) <= 0.0;
 
             // Perform the intersection test
             let intersects = ray.intersects_triangle(&triangle.0, &triangle.1, &triangle.2);
